@@ -1,7 +1,7 @@
-from edecs.models import Event
-from edecs.models import Entity
-from edecs.models import Component
-from edecs.models import System
+from .models import Event
+from .models import Entity
+from .models import Component
+from .models import System
 
 from .managers import EventManager
 from .managers import EntityManager
